<?php

namespace Assetdocs\Incidentreports\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetdocs\Incidentreports\Models\Incidentreport;

class IncidentreportPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the incidentreport.
     *
     * @param User $user
     * @param Incidentreport $incidentreport
     *
     * @return bool
     */
    public function view(User $user, Incidentreport $incidentreport)
    {
        if ($user->canDo('incidentreports.incidentreport.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $incidentreport->user_id;
    }

    /**
     * Determine if the given user can create a incidentreport.
     *
     * @param User $user
     * @param Incidentreport $incidentreport
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('incidentreports.incidentreport.create');
    }

    /**
     * Determine if the given user can update the given incidentreport.
     *
     * @param User $user
     * @param Incidentreport $incidentreport
     *
     * @return bool
     */
    public function update(User $user, Incidentreport $incidentreport)
    {
        if ($user->canDo('incidentreports.incidentreport.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $incidentreport->user_id;
    }

    /**
     * Determine if the given user can delete the given incidentreport.
     *
     * @param User $user
     * @param Incidentreport $incidentreport
     *
     * @return bool
     */
    public function destroy(User $user, Incidentreport $incidentreport)
    {
        if ($user->canDo('incidentreports.incidentreport.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $incidentreport->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
