<?php

namespace Assetdocs\Incidentreports\Providers;

use Illuminate\Support\ServiceProvider;

class IncidentreportsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'incidentreports');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'incidentreports');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('incidentreports', function ($app) {
            return $this->app->make('Assetdocs\Incidentreports\Incidentreports');
        });

        // Bind Incidentreport to repository
        $this->app->bind(
            \Assetdocs\Incidentreports\Interfaces\IncidentreportRepositoryInterface::class,
            \Assetdocs\Incidentreports\Repositories\Eloquent\IncidentreportRepository::class
        );

        $this->app->register(\Assetdocs\Incidentreports\Providers\AuthServiceProvider::class);
        $this->app->register(\Assetdocs\Incidentreports\Providers\EventServiceProvider::class);
        $this->app->register(\Assetdocs\Incidentreports\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['incidentreports'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/incidentreports.php')], 'config');

        // Publish view files
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/incidentreports')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/incidentreports')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public folder.
        $this->publishes([__DIR__ . '/../../../../public' => public_path('/')], 'public');
    }
}
